=======
History
=======

0.1.83 (2025-05-14)
-------------------

* Fixed Windows installation by using built-in winsound module
* Removed problematic playsound dependency
* Enhanced cross-platform audio support
* Simplified installation process for all platforms

0.1.79 (2025-05-14)
-------------------

* Added Windows support without requiring Visual C++ Build Tools
* Using playsound library for audio on Windows platforms
* Added platform-specific audio playback handling
* Improved documentation with Windows installation guide

0.1.33 (2025-05-10)
-------------------

* Minor bug fixes and improvements.
* Bumped version for PyPI release

0.1.32 (2020-07-03)
-------------------

* First release on PyPI.
